@@ -1,19 +1,35 @@
-from NumberScript.interpreter import Interpreter
+from . import interpreter
 import argparse
 import os
 from datetime import datetime
 
 now = datetime.now()
-
 current_time = now.strftime("%H:%M:%S")
 
+Interpreter = interpreter.Interpreter
+
 parser = argparse.ArgumentParser()
-
 parser.add_argument("-f", "--file", help="file to interpret")
-
+parser.add_argument("-v", "--version", action="store_true", help="show version")
 args = parser.parse_args()
+
+ver = "1.8.0"
+
 run = True
 
+help = """
+0 <- start
+1 <- end
+2thing <- print
+3name:value <- var
+4number[=/!/</>] <- Compare
+5 <- pass
+6 <- For-loops
+% <- comment
+^number[+/-/\//]number <- Math-Operation-Start
+?conditon:True:False <- If-Else
+"""
+
 space = ""
 for j in range(0, 16):
     space += " "
@@ -24,12 +40,15 @@ for k in range(0, len(os.name)):
 if args.file:
     with open(args.file, "r") as file:
         code = file.read()
-        Interpreter.interpret(code)
+        code = code.replace("\n", " ")
+        Interpreter.interpret(Interpreter, code)
+elif args.version:
+    print(f"Version: {ver}")
 else:
     print(f"""
         +------------------------------------------+
         | NumberScript Shell: Type 'exit' to exit. |
-        | Version: 1.0 Machine: {os.name} {space}  |
+        | Version: {ver} Machine: {os.name} {space}|
         | Type 'help' for more information.        |
         | {current_time}                                 |
         +------------------------------------------+
@@ -38,5 +57,7 @@ else:
         code = input(">")
         if code == "exit":
             run = False
+        elif code == "help":
+            print(help)
         else:
-            Interpreter.interpret(code)
\ No newline at end of file
+            Interpreter.interpret(Interpreter, code)
\ No newline at end of file
